summaryrefslogtreecommitdiffstats
path: root/contrib/gcc/sched-int.h
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/gcc/sched-int.h')
-rw-r--r--contrib/gcc/sched-int.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/contrib/gcc/sched-int.h b/contrib/gcc/sched-int.h
index 725bf2a..1b19656 100644
--- a/contrib/gcc/sched-int.h
+++ b/contrib/gcc/sched-int.h
@@ -20,6 +20,9 @@ along with GCC; see the file COPYING. If not, write to the Free
Software Foundation, 59 Temple Place - Suite 330, Boston, MA
02111-1307, USA. */
+/* Pointer to data describing the current DFA state. */
+extern state_t curr_state;
+
/* Forward declaration. */
struct ready_list;
@@ -106,7 +109,7 @@ struct deps
int clobbers_length;
} *reg_last;
- /* Element N is set for each register that has any non-zero element
+ /* Element N is set for each register that has any nonzero element
in reg_last[N].{uses,sets,clobbers}. */
regset_head reg_last_in_use;
};
@@ -190,7 +193,7 @@ struct haifa_insn_data
int dep_count;
/* An encoding of the blockage range function. Both unit and range
- are coded. */
+ are coded. This member is used only for old pipeline interface. */
unsigned int blockage;
/* Number of instructions referring to this insn. */
@@ -202,7 +205,8 @@ struct haifa_insn_data
short cost;
- /* An encoding of the function units used. */
+ /* An encoding of the function units used. This member is used only
+ for old pipeline interface. */
short units;
/* This weight is an estimation of the insn's contribution to
@@ -313,4 +317,4 @@ extern int insn_unit PARAMS ((rtx));
extern int insn_cost PARAMS ((rtx, rtx, rtx));
extern rtx get_unit_last_insn PARAMS ((int));
extern int actual_hazard_this_instance PARAMS ((int, int, rtx, int, int));
-
+extern void print_insn PARAMS ((char *, rtx, int));
OpenPOWER on IntegriCloud